package com.logicbig.example;

import org.hibernate.validator.internal.engine.ConfigurationImpl;
import org.hibernate.validator.messageinterpolation.ExpressionLanguageFeatureLevel;
import javax.validation.*;
import javax.validation.constraints.Size;

public class ValidatedValueExample {

    private static class TestBean {

        @Size(min = 5, message = "The name '${validatedValue}' must be at least {min}" +
                            " characters long. Length found: '${validatedValue.length()}'")
        private String name;

        public String getName () {
            return name;
        }

        public void setName (String name) {
            this.name = name;
        }
    }

    public static void main (String[] args) {
        TestBean testBean = new TestBean();
        testBean.setName("Mike");

        Configuration<?> config = Validation.byDefaultProvider().configure();

        //6.2.0.Final
        ((ConfigurationImpl)config).constraintExpressionLanguageFeatureLevel(
                ExpressionLanguageFeatureLevel.BEAN_METHODS);

        ValidatorFactory factory = config.buildValidatorFactory();
        Validator validator = factory.getValidator();
        validator.validate(testBean).stream().forEach(ValidatedValueExample::printError);
        factory.close();
    }

    private static void printError (
                        ConstraintViolation<TestBean> violation) {

        System.out.println(violation.getMessage());
    }
}